diff --git a/tools/gce_setup/grpc_docker.sh b/tools/gce_setup/grpc_docker.sh
index 980a4f6932a2dfd234120b6f6efdd3532cd12fac..3499735f4abdf5322acfa43611991bb0d579bdd4 100755
--- a/tools/gce_setup/grpc_docker.sh
+++ b/tools/gce_setup/grpc_docker.sh
@@ -1020,7 +1020,7 @@ grpc_interop_gen_node_cmd() {
   echo $the_cmd
 }
 
 # constructs the full dockerized node interop test cmd.
 #
 # call-seq:
 #   flags= .... # generic flags to include the command
@@ -1033,6 +1033,21 @@ grpc_cloud_prod_gen_node_cmd() {
   echo $the_cmd
 }
 
+# constructs the full dockerized node service_account auth interop test cmd.
+#
+# call-seq:
+#   flags= .... # generic flags to include the command
+#   cmd=$($grpc_gen_test_cmd $flags)
+grpc_cloud_prod_auth_service_account_creds_gen_node_cmd() {
+  local cmd_prefix="sudo docker run grpc/node";
+  local test_script="/usr/bin/nodejs /var/local/git/grpc/src/node/interop/interop_client.js --use_tls=true";
+  local gfe_flags=$(_grpc_prod_gfe_flags);
+  local env_prefix="SSL_CERT_FILE=/cacerts/roots.pem"
+  env_prefix+=" GOOGLE_APPLICATION_CREDENTIALS=/service_account/stubbyCloudTestingTest-7dd63462c60c.json"
+  local the_cmd="$env_prefix $cmd_prefix $test_script $gfe_flags $@";
+  echo $the_cmd
+}
+
 # constructs the full dockerized cpp interop test cmd.
 #
 # call-seq:
@@ -1020,7 +1020,7 @@ grpc_interop_gen_node_cmd() {
 }
 
-# constructs the full dockerized node interop test cmd.
+# constructs the full dockerized node gce=>prod interop test cmd.
 #
 # call-seq: